@@ -6,6 +6,10 @@ mainwindow::mainwindow(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::mainwindow)
 {
+    
+    this->setAttribute(Qt::WA_Maemo5StackedWindow);
+    this->setWindowFlags(Qt::Window);
+    
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
     ui->setupUi(this);
@@ -27,7 +31,7 @@ mainwindow::mainwindow(QWidget *parent) :
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     orientationChanged();
     readvalues();
-    abouttext = "CSSU Transitions Tuner ver. 0.0.6<br /><br />Auhtor: d-iivil<br />Licence: GPL";
+    abouttext = "CSSU Transitions Tuner ver. 0.0.7<br /><br />Auhtor: d-iivil<br />Licence: GPL";
 }
 
 mainwindow::~mainwindow()
