@@ -20,6 +20,7 @@ public:
     ~mainwindow();
     void readvalues();
     void storevalues();
+    QString abouttext;
 
 private:
     Ui::mainwindow *ui;
@@ -27,8 +28,11 @@ private:
 
 
 private slots:
+    void on_pushButton_5_clicked();
+    void on_pushButton_3_clicked();
     void on_pushButton_2_clicked();
     void on_pushButton_clicked();
+    void orientationChanged();
 };
 
 #endif // MAINWINDOW_H
